@@ -44,13 +44,12 @@
 //!         Event::RedrawRequested(_) => {
 //!             let output_frame = surface.get_current_texture().unwrap();
 //!             let output_view = output_frame.texture.create_view(&Default::default());
-//!             {
-//!                 let frame = smaa_target.start_frame(&device, &queue, &output_view);
+//!             let smaa_frame = smaa_target.start_frame(&device, &queue, &output_view);
 //!
-//!                 // Render the scene into `*frame`.
-//!                 // [...]
+//!             // Render the scene into `*smaa_frame`.
+//!             // [...]
 //!
-//!             }
+//!             smaa_frame.resolve();
 //!             output_frame.present();
 //!         }
 //!         _ => {}
@@ -120,10 +119,7 @@ impl BindGroupLayouts {
                         wgpu::BindGroupLayoutEntry {
                             binding: 0,
                             visibility: wgpu::ShaderStages::FRAGMENT,
-                            ty: wgpu::BindingType::Sampler {
-                                filtering: true,
-                                comparison: false,
-                            },
+                            ty: wgpu::BindingType::Sampler(wgpu::SamplerBindingType::Filtering),
                             count: None,
                         },
                         wgpu::BindGroupLayoutEntry {
@@ -156,10 +152,7 @@ impl BindGroupLayouts {
                         wgpu::BindGroupLayoutEntry {
                             binding: 0,
                             visibility: wgpu::ShaderStages::FRAGMENT,
-                            ty: wgpu::BindingType::Sampler {
-                                filtering: true,
-                                comparison: false,
-                            },
+                            ty: wgpu::BindingType::Sampler(wgpu::SamplerBindingType::Filtering),
                             count: None,
                         },
                         wgpu::BindGroupLayoutEntry {
@@ -212,10 +205,7 @@ impl BindGroupLayouts {
                         wgpu::BindGroupLayoutEntry {
                             binding: 0,
                             visibility: wgpu::ShaderStages::FRAGMENT,
-                            ty: wgpu::BindingType::Sampler {
-                                filtering: true,
-                                comparison: false,
-                            },
+                            ty: wgpu::BindingType::Sampler(wgpu::SamplerBindingType::Filtering),
                             count: None,
                         },
                         wgpu::BindGroupLayoutEntry {
@@ -303,6 +293,7 @@ impl Pipelines {
             primitive: Default::default(),
             multisample: Default::default(),
             depth_stencil: None,
+            multiview: None,
         });
 
         let blend_weight_layout = device.create_pipeline_layout(&wgpu::PipelineLayoutDescriptor {
@@ -343,6 +334,7 @@ impl Pipelines {
             primitive: Default::default(),
             multisample: Default::default(),
             depth_stencil: None,
+            multiview: None,
         });
 
         let neighborhood_blending_layout =
@@ -385,6 +377,7 @@ impl Pipelines {
                 primitive: Default::default(),
                 multisample: Default::default(),
                 depth_stencil: None,
+                multiview: None,
             });
 
         Self {
@@ -676,7 +669,7 @@ impl SmaaTarget {
         }
     }
 
-    /// Start rendering a frame. Dropping the returned frame object will resolve the scene into the provided output_view.
+    /// Start rendering a frame. Dropping or calling resolve() the returned frame object will resolve the scene into the provided output_view.
     pub fn start_frame<'a>(
         &'a mut self,
         device: &'a wgpu::Device,
@@ -699,6 +692,12 @@ pub struct SmaaFrame<'a> {
     queue: &'a wgpu::Queue,
     output_view: &'a wgpu::TextureView,
 }
+impl<'a> SmaaFrame<'a> {
+    /// Resolve the multisampled image into the output texture.
+    pub fn resolve(self) {
+        std::mem::drop(self);
+    }
+}
 impl<'a> std::ops::Deref for SmaaFrame<'a> {
     type Target = wgpu::TextureView;
     fn deref(&self) -> &Self::Target {
