@@ -1,4 +1,4 @@
-use shaderc::ShaderKind;
+use naga::FastHashMap;
 
 #[allow(dead_code)]
 pub enum ShaderQuality {
@@ -101,8 +101,11 @@ impl ShaderStage {
                  layout(set = 0, binding = 2) uniform texture2D colorTex;
                  layout(location = 0) out float2 OutColor;
                  void main() {
-                     float4 offset[3] = float4[](offset0, offset1, offset2);
-                     OutColor = SMAALumaEdgeDetectionPS(texcoord, offset, colorTex);
+                    float4 offset[3];
+                    offset[0] = offset0;
+                    offset[1] = offset1;
+                    offset[2] = offset2;
+                    OutColor = SMAALumaEdgeDetectionPS(texcoord, offset, colorTex);
                  }"
             }
             ShaderStage::BlendingWeightPS => {
@@ -117,7 +120,10 @@ impl ShaderStage {
                  layout(location = 0) out float4 OutColor;
                  void main() {
                      vec4 subsampleIndices = vec4(0);
-                     float4 offset[3] = float4[](offset0, offset1, offset2);
+                     float4 offset[3];
+                     offset[0] = offset0;
+                     offset[1] = offset1;
+                     offset[2] = offset2;
                      OutColor = SMAABlendingWeightCalculationPS(texcoord, pixcoord, offset,
                          edgesTex, areaTex, searchTex, subsampleIndices);
                  }"
@@ -162,7 +168,7 @@ impl ShaderSource {
         format!(
             "#version 450 core
             #extension GL_EXT_samplerless_texture_functions: require
-            #define SMAA_GLSL_3
+            #define SMAA_GLSL_4
             #define SMAA_PRESET_{0}
             #define SMAA_INCLUDE_{1} 0
             #define SMAA_RT_METRICS uniforms.rt
@@ -184,27 +190,17 @@ impl ShaderSource {
         stage: ShaderStage,
         name: &'static str,
     ) -> wgpu::ShaderModule {
-        let source = self.get_stage(stage);
-        let mut glsl_compiler = shaderc::Compiler::new().unwrap();
-        let spirv = glsl_compiler
-            .compile_into_spirv(
-                &source,
-                if stage.is_vertex_shader() {
-                    ShaderKind::Vertex
-                } else {
-                    ShaderKind::Fragment
-                },
-                name,
-                "main",
-                None,
-            )
-            .unwrap()
-            .as_binary()
-            .to_vec();
-
         device.create_shader_module(&wgpu::ShaderModuleDescriptor {
             label: Some(name),
-            source: wgpu::ShaderSource::SpirV(spirv.into()),
+            source: wgpu::ShaderSource::Glsl {
+                shader: self.get_stage(stage).into(),
+                stage: if stage.is_vertex_shader() {
+                    naga::ShaderStage::Vertex
+                } else {
+                    naga::ShaderStage::Fragment
+                },
+                defines: FastHashMap::default(),
+            }
         })
     }
 }
